@@ -3,7 +3,7 @@
 // Purpose:     FFMPEG Media Decoder
 // Author:      Alex Thuering
 // Created:     21.07.2007
-// RCS-ID:      $Id: mediadec_ffmpeg.cpp,v 1.32 2015/09/21 13:23:51 ntalex Exp $
+// RCS-ID:      $Id: mediadec_ffmpeg.cpp,v 1.34 2016/02/29 13:09:59 ntalex Exp $
 // Copyright:   (c) Alex Thuering
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -30,6 +30,9 @@ extern "C" {
 #define av_frame_alloc avcodec_alloc_frame
 #define av_frame_free avcodec_free_frame
 #endif
+#if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(57, 0, 0)
+#define av_packet_unref av_free_packet
+#endif
 
 wxFfmpegMediaDecoder::wxFfmpegMediaDecoder(): m_formatCtx(NULL), m_videoStream(-1), m_codecCtx(NULL), m_frame(NULL),
 		m_width(0), m_height(0) {
@@ -263,9 +266,9 @@ wxImage wxFfmpegMediaDecoder::GetNextFrame() {
 			avcodec_decode_video2(m_codecCtx, m_frame, &frameFinished, &packet);
 			if (frameFinished) {
 				SwsContext* imgConvertCtx = sws_getContext(m_codecCtx->width, m_codecCtx->height, m_codecCtx->pix_fmt,
-						m_width, m_height, PIX_FMT_RGB24, SWS_BICUBIC, NULL, NULL, NULL);
+						m_width, m_height, AV_PIX_FMT_RGB24, SWS_BICUBIC, NULL, NULL, NULL);
 				if (imgConvertCtx == NULL) {
-					av_free_packet(&packet);
+					av_packet_unref(&packet);
 					return wxImage();
 				}
 
@@ -273,13 +276,13 @@ wxImage wxFfmpegMediaDecoder::GetNextFrame() {
 				uint8_t *rgbSrc[3] = { img.GetData(), NULL, NULL };
 				int rgbStride[3] = { 3 * m_width, 0, 0 };
 				sws_scale(imgConvertCtx, m_frame->data, m_frame->linesize, 0, m_codecCtx->height, rgbSrc, rgbStride);
-				av_free_packet(&packet);
+				av_packet_unref(&packet);
 				sws_freeContext(imgConvertCtx);
 				return img;
 			}
 		}
 		// free the packet that was allocated by av_read_frame
-		av_free_packet(&packet);
+		av_packet_unref(&packet);
 	}
 	return wxImage();
 }
